pub struct GalleryReference {
pub gallery_template_id: Option<String>,
pub host: Option<String>,
pub is_modified: Option<bool>,
pub owner: Option<String>,
pub repository: Option<String>,
pub signature: Option<String>,
pub template_developer_id: Option<String>,
pub version: Option<String>,
}Expand description
Represents the link between a custom template and an entry on the Community Template Gallery site.
This type is not used in any activity, and only used as part of another schema.
Fields
gallery_template_id: Option<String>ID for the gallery template that is generated once during first sync and travels with the template redirects.
host: Option<String>The name of the host for the community gallery template.
is_modified: Option<bool>If a user has manually edited the community gallery template.
owner: Option<String>The name of the owner for the community gallery template.
repository: Option<String>The name of the repository for the community gallery template.
signature: Option<String>The signature of the community gallery template as computed at import time. This value is recomputed whenever the template is updated from the gallery.
template_developer_id: Option<String>The developer id of the community gallery template. This value is set whenever the template is created from the gallery.
version: Option<String>The version of the community gallery template.