pub struct RevertZoneResponse {
pub zone: Option<Zone>,
}Expand description
The result of reverting a zone in a workspace.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- containers workspaces zones revert accounts (response)
Fields
zone: Option<Zone>Zone as it appears in the latest container version since the last workspace synchronization operation. If no zone is present, that means the zone was deleted in the latest container version.