pub struct Workspace {
pub account_id: Option<String>,
pub container_id: Option<String>,
pub description: Option<String>,
pub fingerprint: Option<String>,
pub name: Option<String>,
pub path: Option<String>,
pub tag_manager_url: Option<String>,
pub workspace_id: Option<String>,
}Expand description
Represents a Google Tag Manager Container Workspace.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- containers workspaces create accounts (request|response)
- containers workspaces get accounts (response)
- containers workspaces update accounts (request|response)
Fields
account_id: Option<String>GTM Account ID.
container_id: Option<String>GTM Container ID.
description: Option<String>Workspace description.
fingerprint: Option<String>The fingerprint of the GTM Workspace as computed at storage time. This value is recomputed whenever the workspace is modified.
name: Option<String>Workspace display name.
path: Option<String>GTM Workspace’s API relative path.
tag_manager_url: Option<String>Auto generated link to the tag manager UI
workspace_id: Option<String>The Workspace ID uniquely identifies the GTM Workspace.