Struct google_tagmanager2::BuiltInVariable
source · pub struct BuiltInVariable {
pub workspace_id: Option<String>,
pub container_id: Option<String>,
pub path: Option<String>,
pub account_id: Option<String>,
pub type_: Option<String>,
pub name: Option<String>,
}Expand description
Built-in variables are a special category of variables that are pre-created and non-customizable. They provide common functionality like accessing propeties of the gtm data layer, monitoring clicks, or accessing elements of a page URL.
This type is not used in any activity, and only used as part of another schema.
Fields
workspace_id: Option<String>GTM Workspace ID.
container_id: Option<String>GTM Container ID.
path: Option<String>GTM BuiltInVariable’s API relative path.
account_id: Option<String>GTM Account ID.
type_: Option<String>Type of built-in variable.
name: Option<String>Name of the built-in variable to be used to refer to the built-in variable.