[−][src]Struct google_tagmanager2::CreateBuiltInVariableResponse
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
built_in_variable: Option<Vec<BuiltInVariable>>List of created built-in variables.