Struct google_tagmanager2::WorkspaceProposalUser
[−]
[src]
pub struct WorkspaceProposalUser {
pub gaia_id: Option<String>,
pub type_: Option<String>,
}Represents an external user or internal Google Tag Manager system.
This type is not used in any activity, and only used as part of another schema.
Fields
gaia_id: Option<String>
Gaia id associated with a user, absent for the Google Tag Manager system.
type_: Option<String>
User type distinguishes between a user and the Google Tag Manager system.